@@ -36,6 +36,12 @@ class ChangeRecorderPrivate;
  * is online again. Therefore the agent doesn't have to care about
  * online/offline mode in its synchronization algorithm.
  *
+ * Unlike Akonadi::Monitor this class only emits one change signal at a
+ * time. To receive the next one you need to explicitly call replayNext().
+ * If a signal is emitted that has no receivers, it's automatically skipped,
+ * which means you only need to connect to signals you are actually interested
+ * in.
+ *
  * @author Volker Krause <vkrause@kde.org>
  */
 class AKONADI_EXPORT ChangeRecorder : public Monitor
@@ -75,6 +81,11 @@ class AKONADI_EXPORT ChangeRecorder : public Monitor
      */
     void setChangeRecordingEnabled( bool enable );
 
+    /**
+     * Debugging: dump current list of notifications, as saved on disk.
+     */
+    QString dumpNotificationListToString() const;
+
   public Q_SLOTS:
     /**
      * Replay the next change notification and erase the previous one from the record.
