@@ -23,7 +23,7 @@
 #include "akonadi_export.h"
 
 #include <akonadi/collection.h>
-
+#include <akonadi/collectiondialog.h>
 #include <khbox.h>
 
 namespace Akonadi {
@@ -109,6 +109,8 @@ class AKONADI_EXPORT CollectionRequester : public KHBox
      */
     Collection::Rights accessRightsFilter() const;
 
+    void changeCollectionDialogOptions( CollectionDialog::CollectionDialogOptions options );
+
   public Q_SLOTS:
     /**
      * Sets the @p collection of the requester.
