@@ -25,16 +25,16 @@
 
 #include <QtCore/QEvent>
 #include <QtCore/QList>
-#include <QtGui/QApplication>
-#include <QtGui/QBoxLayout>
-#include <QtGui/QButtonGroup>
-#include <QtGui/QCheckBox>
-#include <QtGui/QFrame>
-#include <QtGui/QGridLayout>
-#include <QtGui/QGroupBox>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QPushButton>
+#include <QApplication>
+#include <QBoxLayout>
+#include <QButtonGroup>
+#include <QCheckBox>
+#include <QFrame>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QKeyEvent>
+#include <QLabel>
+#include <QPushButton>
 
 #include <kacceleratormanager.h>
 #include <kcombobox.h>
@@ -120,16 +120,18 @@ void AddressSelectionWidget::setAddresses( const KABC::Address::List &addresses
 void AddressSelectionWidget::setCurrentAddress( const KABC::Address &address )
 {
   const int index = mAddresses.indexOf( address );
-  if ( index != -1 )
+  if ( index != -1 ) {
     setCurrentIndex( index );
+  }
 }
 
 KABC::Address AddressSelectionWidget::currentAddress() const
 {
-  if ( currentIndex() != -1 && currentIndex() < mAddresses.count() )
+  if ( currentIndex() != -1 && currentIndex() < mAddresses.count() ) {
     return mAddresses.at( currentIndex() );
-  else
+  } else {
     return KABC::Address();
+  }
 }
 
 void AddressSelectionWidget::selected( int index )
@@ -141,8 +143,9 @@ void AddressSelectionWidget::selected( int index )
 void AddressSelectionWidget::updateView()
 {
   clear();
-  for ( int i = 0; i < mAddresses.count(); ++i )
+  for ( int i = 0; i < mAddresses.count(); ++i ) {
     addItem( KABC::Address::typeLabel( mAddresses.at( i ).type() ) );
+  }
 }
 
 
@@ -152,8 +155,9 @@ AddressTypeCombo::AddressTypeCombo( QWidget *parent )
     mType( KABC::Address::Home ),
     mLastSelected( 0 )
 {
-  for ( int i = 0; i < KABC::Address::typeList().count(); ++i )
+  for ( int i = 0; i < KABC::Address::typeList().count(); ++i ) {
     mTypeList.append( KABC::Address::typeList().at( i ) );
+  }
   mTypeList.append( -1 ); // Others...
 
   update();
@@ -189,10 +193,11 @@ void AddressTypeCombo::update()
 
   clear();
   for ( int i = 0; i < mTypeList.count(); ++i ) {
-    if ( mTypeList.at( i ) == -1 ) // "Other..." entry
+    if ( mTypeList.at( i ) == -1 ) { // "Other..." entry
       addItem( i18nc( "@item:inlistbox Category of contact info field", "Other..." ) );
-    else
+    } else {
       addItem( KABC::Address::typeLabel( KABC::Address::Type( mTypeList.at( i ) ) ) );
+    }
   }
 
   setCurrentIndex( mLastSelected = mTypeList.indexOf( mType ) );
@@ -202,9 +207,9 @@ void AddressTypeCombo::update()
 
 void AddressTypeCombo::selected( int pos )
 {
-  if ( mTypeList.at( pos ) == -1 )
+  if ( mTypeList.at( pos ) == -1 ) {
     otherSelected();
-  else {
+  } else {
     mType = KABC::Address::Type( mTypeList.at( pos ) );
     mLastSelected = pos;
   }
@@ -215,8 +220,9 @@ void AddressTypeCombo::otherSelected()
   AutoQPointer<AddressTypeDialog> dlg = new AddressTypeDialog( mType, this );
   if ( dlg->exec() ) {
     mType = dlg->type();
-    if ( !mTypeList.contains( mType ) )
+    if ( !mTypeList.contains( mType ) ) {
       mTypeList.insert( mTypeList.at( mTypeList.count() - 1 ), mType );
+    }
   } else {
     setType( KABC::Address::Type( mTypeList.at( mLastSelected ) ) );
   }
@@ -309,8 +315,9 @@ void AddressEditWidget::deleteAddress()
 {
   const int result = KMessageBox::questionYesNo( this, i18n( "Do you really want to delete this address?" ) );
 
-  if ( result != KMessageBox::Yes )
+  if ( result != KMessageBox::Yes ) {
     return;
+  }
 
   mAddressList.removeAt( mAddressSelectionWidget->currentIndex() );
   mAddressSelectionWidget->setAddresses( mAddressList );
@@ -334,17 +341,18 @@ void AddressEditWidget::updateAddressView()
 {
   const KABC::Address address = mAddressSelectionWidget->currentAddress();
 
-  if ( address.isEmpty() )
+  if ( address.isEmpty() ) {
     mAddressView->setText( QString() );
-  else
+  } else {
     mAddressView->setText( address.formattedAddress( mName ) );
+  }
 }
 
 void AddressEditWidget::updateButtons()
 {
   mCreateButton->setEnabled( !mReadOnly );
-  mEditButton->setEnabled( !mReadOnly && (mAddressList.count() > 0) );
-  mDeleteButton->setEnabled( !mReadOnly && (mAddressList.count() > 0) );
+  mEditButton->setEnabled( !mReadOnly && ( mAddressList.count() > 0 ) );
+  mDeleteButton->setEnabled( !mReadOnly && ( mAddressList.count() > 0 ) );
 }
 
 void AddressEditWidget::loadContact( const KABC::Addressee &contact )
@@ -370,14 +378,16 @@ void AddressEditWidget::storeContact( KABC::Addressee &contact ) const
 {
   // delete all previous addresses
   const KABC::Address::List oldAddresses = contact.addresses();
-  for ( int i = 0; i < oldAddresses.count(); ++i )
+  for ( int i = 0; i < oldAddresses.count(); ++i ) {
     contact.removeAddress( oldAddresses.at( i ) );
+  }
 
   // insert the new ones
   for ( int i = 0; i < mAddressList.count(); ++i ) {
     const KABC::Address address( mAddressList.at( i ) );
-    if ( !address.isEmpty() )
+    if ( !address.isEmpty() ) {
       contact.insertAddress( address );
+    }
   }
 }
 
@@ -472,8 +482,9 @@ void AddressEditDialog::editLabel()
   QString result = KInputDialog::getMultiLineText( KABC::Address::labelLabel(),
                                                    KABC::Address::labelLabel(),
                                                    mLabel, &ok, this );
-  if ( ok )
+  if ( ok ) {
     mLabel = result;
+  }
 }
 
 void AddressEditDialog::setAddress( const KABC::Address &address )
@@ -489,11 +500,12 @@ void AddressEditDialog::setAddress( const KABC::Address &address )
   mLabel = mAddress.label();
   mPreferredCheckBox->setChecked( mAddress.type() & KABC::Address::Pref );
 
-  if ( mAddress.isEmpty() )
+  if ( mAddress.isEmpty() ) {
     mCountryCombo->setItemText( mCountryCombo->currentIndex(),
                                 KGlobal::locale()->countryCodeToName( KGlobal::locale()->country() ) );
-  else
+  } else {
     mCountryCombo->setItemText( mCountryCombo->currentIndex(), mAddress.country() );
+  }
 
   mStreetTextEdit->setFocus();
 }
@@ -513,8 +525,9 @@ KABC::Address AddressEditDialog::address() const
 
   if ( mPreferredCheckBox->isChecked() ) {
     address.setType( address.type() | KABC::Address::Pref );
-  } else
-    address.setType( address.type() & ~(KABC::Address::Pref) );
+  } else {
+    address.setType( address.type() & ~( KABC::Address::Pref ) );
+  }
 
   return address;
 }
@@ -523,8 +536,9 @@ void AddressEditDialog::fillCountryCombo()
 {
   QStringList countries;
 
-  foreach ( const QString &cc, KGlobal::locale()->allCountriesList() )
+  foreach ( const QString &cc, KGlobal::locale()->allCountriesList() ) {
     countries.append( KGlobal::locale()->countryCodeToName( cc ) );
+  }
 
   qSort( countries.begin(), countries.end(), LocaleAwareLessThan() );
 
@@ -545,7 +559,7 @@ AddressTypeDialog::AddressTypeDialog( KABC::Address::Type type, QWidget *parent
   setButtons( Ok | Cancel );
   setDefaultButton( Ok );
 
-  QWidget *page = new QWidget(this);
+  QWidget *page = new QWidget( this );
   setMainWidget( page );
   QVBoxLayout *layout = new QVBoxLayout( page );
   layout->setSpacing( KDialog::spacingHint() );
@@ -569,8 +583,9 @@ AddressTypeDialog::AddressTypeDialog( KABC::Address::Type type, QWidget *parent
     cb->setChecked( type & mTypeList[ i ] );
     buttonLayout->addWidget( cb, row, i%3 );
 
-    if( i%3 == 2 )
+    if ( i % 3 == 2 ) {
         ++row;
+    }
     mGroup->addButton( cb );
   }
 }
@@ -584,11 +599,11 @@ KABC::Address::Type AddressTypeDialog::type() const
   KABC::Address::Type type;
   for ( int i = 0; i < mGroup->buttons().count(); ++i ) {
     QCheckBox *box = dynamic_cast<QCheckBox*>( mGroup->buttons().at( i ) );
-    if ( box && box->isChecked() )
+    if ( box && box->isChecked() ) {
       type |= mTypeList[ i ];
+    }
   }
 
   return type;
 }
 
-#include "addresseditwidget.moc"
