@@ -32,9 +32,9 @@
 
 #include <QtCore/QPointer>
 #include <QtCore/QUuid>
-#include <QtGui/QGridLayout>
-#include <QtGui/QPushButton>
-#include <QtGui/QTreeView>
+#include <QGridLayout>
+#include <QPushButton>
+#include <QTreeView>
 #include <QSortFilterProxyModel>
 
 void splitCustomField( const QString &str, QString &app, QString &name, QString &value )
@@ -106,8 +106,9 @@ void CustomFieldsEditWidget::loadContact( const KABC::Addressee &contact )
     splitCustomField( custom, app, name, value );
 
     // skip all well-known fields that have separated editor widgets
-    if ( custom.startsWith( QLatin1String( "messaging/" ) ) ) // IM addresses
+    if ( custom.startsWith( QLatin1String( "messaging/" ) ) ) { // IM addresses
       continue;
+    }
 
     if ( app == QLatin1String( "KADDRESSBOOK" ) ) {
       static QSet<QString> blacklist;
@@ -131,8 +132,9 @@ void CustomFieldsEditWidget::loadContact( const KABC::Addressee &contact )
                   << QLatin1String( "CRYPTOENCRYPTPREF" );
       }
 
-      if ( blacklist.contains( name ) ) // several KAddressBook specific fields
+      if ( blacklist.contains( name ) ) { // several KAddressBook specific fields
         continue;
+      }
     }
 
     // check whether it correspond to a local custom field
@@ -184,10 +186,11 @@ void CustomFieldsEditWidget::storeContact( KABC::Addressee &contact ) const
   foreach ( const CustomField &customField, customFields ) {
     // write back values for local and global scope, leave external untouched
     if ( customField.scope() != CustomField::ExternalScope ) {
-      if ( !customField.value().isEmpty() )
+      if ( !customField.value().isEmpty() ) {
         contact.insertCustom( QLatin1String( "KADDRESSBOOK" ), customField.key(), customField.value() );
-      else
+      } else {
         contact.removeCustom( QLatin1String( "KADDRESSBOOK" ), customField.key() );
+      }
     }
   }
 
@@ -207,8 +210,9 @@ void CustomFieldsEditWidget::storeContact( KABC::Addressee &contact ) const
         }
       }
 
-      if ( !fieldStillExists )
+      if ( !fieldStillExists ) {
         contact.removeCustom( QLatin1String( "KADDRESSBOOK" ), oldCustomField.key() );
+      }
     }
   }
 
@@ -236,8 +240,9 @@ void CustomFieldsEditWidget::setLocalCustomFieldDescriptions( const QVariantList
 {
   mLocalCustomFields.clear();
 
-  foreach ( const QVariant &description, descriptions )
+  foreach ( const QVariant &description, descriptions ) {
     mLocalCustomFields.append( CustomField::fromVariantMap( description.toMap(), CustomField::LocalScope ) );
+  }
 }
 
 QVariantList CustomFieldsEditWidget::localCustomFieldDescriptions() const
@@ -246,8 +251,9 @@ QVariantList CustomFieldsEditWidget::localCustomFieldDescriptions() const
 
   QVariantList descriptions;
   foreach ( const CustomField &field, customFields ) {
-    if ( field.scope() == CustomField::LocalScope )
+    if ( field.scope() == CustomField::LocalScope ) {
       descriptions.append( field.toVariantMap() );
+    }
   }
 
   return descriptions;
@@ -287,8 +293,9 @@ void CustomFieldsEditWidget::slotAdd()
 void CustomFieldsEditWidget::slotEdit()
 {
   const QModelIndex currentIndex = mView->currentIndex();
-  if ( !currentIndex.isValid() )
+  if ( !currentIndex.isValid() ) {
     return;
+  }
 
   CustomField field;
   field.setKey( mModel->index( currentIndex.row(), 2 ).data( Qt::DisplayRole ).toString() );
@@ -313,8 +320,9 @@ void CustomFieldsEditWidget::slotEdit()
 void CustomFieldsEditWidget::slotRemove()
 {
   const QModelIndex currentIndex = mView->currentIndex();
-  if ( !currentIndex.isValid() )
+  if ( !currentIndex.isValid() ) {
     return;
+  }
 
   if ( KMessageBox::warningContinueCancel( this,
                                            i18nc( "Custom Fields", "Do you really want to delete the selected custom field?" ),
@@ -328,12 +336,11 @@ void CustomFieldsEditWidget::slotRemove()
 void CustomFieldsEditWidget::slotUpdateButtons()
 {
   const bool hasCurrent = mView->currentIndex().isValid();
-  const bool isExternal = (hasCurrent && 
-                           (static_cast<CustomField::Scope>( mView->currentIndex().data( CustomFieldsModel::ScopeRole ).toInt() ) == CustomField::ExternalScope) );
+  const bool isExternal = ( hasCurrent &&
+                            ( static_cast<CustomField::Scope>( mView->currentIndex().data( CustomFieldsModel::ScopeRole ).toInt() ) == CustomField::ExternalScope ) );
 
   mAddButton->setEnabled( !mReadOnly );
   mEditButton->setEnabled( !mReadOnly && hasCurrent && !isExternal );
   mRemoveButton->setEnabled( !mReadOnly && hasCurrent && !isExternal );
 }
 
-#include "customfieldseditwidget.moc"
