@@ -139,7 +139,7 @@ void EmailEditWidget::storeContact( KABC::Addressee &contact ) const
 
   // ... and prepend the one from the line edit
   if ( !mEmailEdit->text().isEmpty() ) {
-    emails.prepend( mEmailEdit->text() );
+      emails.prepend( mEmailEdit->text().toLower() );
   }
 
   contact.setEmails( emails );
@@ -268,7 +268,7 @@ void EmailEditDialog::add()
     return;
   }
 
-  email = KPIMUtils::extractEmailAddress( email );
+  email = KPIMUtils::extractEmailAddress( email.toLower() );
 
   // check if item already available, ignore if so...
   for ( int i = 0; i < mEmailListBox->count(); ++i ) {
@@ -296,7 +296,7 @@ void EmailEditDialog::edit()
     return;
   }
 
-  email = KPIMUtils::extractEmailAddress( email );
+  email = KPIMUtils::extractEmailAddress( email.toLower() );
 
   // check if item already available, ignore if so...
   for ( int i = 0; i < mEmailListBox->count(); ++i ) {
