@@ -61,7 +61,7 @@ KDatePickerPopup::KDatePickerPopup( Items items, const QDate &date, QWidget *par
   : QMenu( parent )
 {
   mItems = items;
-
+  mDate = date;
   mDatePicker = new KDatePicker( this );
   mDatePicker->setCloseButton( false );
 
@@ -70,11 +70,19 @@ KDatePickerPopup::KDatePickerPopup( Items items, const QDate &date, QWidget *par
   connect( mDatePicker, SIGNAL(dateSelected(QDate)),
            SLOT(slotDateChanged(QDate)) );
 
+  connect( this, SIGNAL(aboutToHide()), SLOT(slotHidePickerPopup()));
   mDatePicker->setDate( date );
 
   buildMenu();
 }
 
+void KDatePickerPopup::slotHidePickerPopup()
+{
+    if (mDatePicker->date() != mDate) {
+        emit dateChanged( mDatePicker->date() );
+    }
+}
+
 void KDatePickerPopup::buildMenu()
 {
   if ( isVisible() ) {
@@ -124,9 +132,8 @@ void KDatePickerPopup::setItems( int items )
 }
 #endif
 
-void KDatePickerPopup::slotDateChanged( const QDate &date )
+void KDatePickerPopup::slotDateChanged( const QDate &/*date*/ )
 {
-  emit dateChanged( date );
   hide();
 }
 
