@@ -20,7 +20,7 @@
 #ifndef AKONADI_DRAGDROPMANAGER_P_H
 #define AKONADI_DRAGDROPMANAGER_P_H
 
-#include <QtGui/QAbstractItemView>
+#include <QAbstractItemView>
 
 #include "akonadi/collection.h"
 
@@ -68,7 +68,7 @@ class DragDropManager
 
     /**
      * Set true if we automatic sorting
-     */    
+     */
     void setManualSortingActive(bool active);
 
   private:
