@@ -22,6 +22,7 @@
 
 #include "dbusconnectionpool.h"
 #include "preprocessoradaptor.h"
+#include "servermanager.h"
 
 #include <akonadi/itemfetchjob.h>
 
@@ -37,7 +38,7 @@ PreprocessorBasePrivate::PreprocessorBasePrivate( PreprocessorBase *parent )
 
 void PreprocessorBasePrivate::delayedInit()
 {
-  if ( !DBusConnectionPool::threadConnection().registerService( QLatin1String( "org.freedesktop.Akonadi.Preprocessor." ) + mId ) )
+  if ( !DBusConnectionPool::threadConnection().registerService( ServerManager::agentServiceName( ServerManager::Preprocessor, mId ) ) )
     kFatal() << "Unable to register service at D-Bus: " << DBusConnectionPool::threadConnection().lastError().message();
   AgentBasePrivate::delayedInit();
 }
@@ -90,4 +91,3 @@ void PreprocessorBasePrivate::itemFetched( KJob *job )
   }
 }
 
-#include "preprocessorbase_p.moc"
