@@ -269,6 +269,8 @@ QByteArray ProtocolHelper::itemFetchScopeToByteArray( const ItemFetchScope &fetc
     command += " " AKONADI_PARAM_ALLATTRIBUTES;
   if ( fetchScope.cacheOnly() )
     command += " " AKONADI_PARAM_CACHEONLY;
+  if ( fetchScope.ignoreRetrievalErrors() )
+    command += " " "IGNOREERRORS";
   if ( fetchScope.ancestorRetrieval() != ItemFetchScope::None ) {
     switch ( fetchScope.ancestorRetrieval() ) {
       case ItemFetchScope::Parent:
