@@ -28,9 +28,9 @@
 
 #include <QtCore/QPointer>
 #include <QtCore/QRegExp>
-#include <QtGui/QGroupBox>
-#include <QtGui/QLayout>
-#include <QtGui/QPushButton>
+#include <QGroupBox>
+#include <QLayout>
+#include <QPushButton>
 
 using namespace KABC;
 
@@ -63,7 +63,7 @@ QString AddresseeItem::key( int column, bool ) const
 {
   if ( column == Email ) {
     QString value = text( Email );
-    QRegExp emailRe( QLatin1String( "<\\S*>" ) );
+    const QRegExp emailRe( QLatin1String( "<\\S*>" ) );
     int match = emailRe.indexIn( value );
     if ( match > -1 ) {
       value = value.mid( match + 1, emailRe.matchedLength() - 2 );
@@ -216,7 +216,8 @@ Addressee::List AddresseeDialog::addressees() const
   AddresseeItem *aItem = 0;
 
   if ( d->mMultiple ) {
-    for ( int i = 0; i < d->mSelectedList->topLevelItemCount(); ++i ) {
+    const int numberOfTopItem( d->mSelectedList->topLevelItemCount() );
+    for ( int i = 0; i < numberOfTopItem; ++i ) {
       aItem = dynamic_cast<AddresseeItem *>( d->mSelectedList->topLevelItem( i ) );
       if ( aItem ) {
         al.append( aItem->addressee() );
@@ -272,9 +273,9 @@ void AddresseeDialog::Private::loadAddressBook()
 #ifndef KDEPIM_NO_KRESOURCES
   AddressBook::Iterator it;
   for ( it = mAddressBook->begin(); it != mAddressBook->end(); ++it ) {
-    AddresseeItem *item = new AddresseeItem( mAddresseeList, (*it) );
-    addCompletionItem( (*it).realName(), item );
-    addCompletionItem( (*it).preferredEmail(), item );
+    AddresseeItem *item = new AddresseeItem( mAddresseeList, ( *it ) );
+    addCompletionItem( ( *it ).realName(), item );
+    addCompletionItem( ( *it ).preferredEmail(), item );
   }
 #endif
 }
@@ -351,4 +352,4 @@ void AddresseeDialog::Private::addressBookChanged()
   loadAddressBook();
 }
 
-#include "addresseedialog.moc"
+#include "moc_addresseedialog.cpp"
