@@ -30,13 +30,13 @@
 #include <kcombobox.h>
 
 #include <QtCore/QPointer>
-#include <QtGui/QTreeWidget>
-#include <QtGui/QLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QPushButton>
-#include <QtGui/QGroupBox>
-#include <QtGui/QButtonGroup>
-#include <QtGui/QRadioButton>
+#include <QTreeWidget>
+#include <QLayout>
+#include <QLabel>
+#include <QPushButton>
+#include <QGroupBox>
+#include <QButtonGroup>
+#include <QRadioButton>
 
 using namespace KABC;
 
@@ -85,13 +85,13 @@ EmailSelector::EmailSelector( const QStringList &emails, const QString &current,
   QVBoxLayout *layout = new QVBoxLayout;
 
   QStringList::ConstIterator it;
-  QStringList::ConstIterator end(emails.end());
+  QStringList::ConstIterator end( emails.end() );
   for ( it = emails.begin(); it != end; ++it ) {
     QRadioButton *button = new QRadioButton( *it, box );
     d->mButtonGroup->addButton( button );
     d->mEmailMap.insert( button, *it );
     layout->addWidget( button );
-    if ( (*it) == current ) {
+    if ( ( *it ) == current ) {
       button->setChecked( true );
     }
   }
@@ -451,9 +451,9 @@ void DistributionListEditorWidget::Private::updateEntryView()
 
   DistributionList::Entry::List entries = list->entries();
   DistributionList::Entry::List::ConstIterator it;
-  DistributionList::Entry::List::ConstIterator end(entries.constEnd());
+  DistributionList::Entry::List::ConstIterator end( entries.constEnd() );
   for ( it = entries.constBegin(); it != end; ++it ) {
-    new EntryItem( mEntryView, (*it).addressee(), (*it).email() );
+    new EntryItem( mEntryView, ( *it ).addressee(), ( *it ).email() );
   }
 
   QList<QTreeWidgetItem*> selected = mEntryView->selectedItems();
@@ -468,7 +468,7 @@ void DistributionListEditorWidget::Private::updateAddresseeView()
   mAddresseeView->clear();
 
   AddressBook::ConstIterator it;
-  AddressBook::ConstIterator end(mAddressBook->constEnd());
+  AddressBook::ConstIterator end( mAddressBook->constEnd() );
   for ( it = mAddressBook->constBegin(); it != end; ++it ) {
     new AddresseeItem( mAddresseeView, *it );
   }
@@ -488,4 +488,4 @@ void DistributionListEditorWidget::Private::slotSelectionAddresseeViewChanged()
   mAddEntryButton->setEnabled( state && !mNameCombo->currentText().isEmpty() );
 }
 
-#include "distributionlistdialog.moc"
+#include "moc_distributionlistdialog.cpp"
