@@ -24,12 +24,11 @@
 #include <klocale.h>
 
 #include <QtCore/QPointer>
-#include <QtGui/QButtonGroup>
-#include <QtGui/QGroupBox>
-#include <QtGui/QLayout>
-#include <QtGui/QRadioButton>
+#include <QButtonGroup>
+#include <QGroupBox>
+#include <QLayout>
+#include <QRadioButton>
 
-#include "emailselectdialog.moc"
 
 using namespace KABC;
 
@@ -59,12 +58,12 @@ EmailSelectDialog::EmailSelectDialog( const QStringList &emails,
   QVBoxLayout *layout = new QVBoxLayout;
 
   QStringList::ConstIterator it;
-  QStringList::ConstIterator end(emails.end());
+  QStringList::ConstIterator end( emails.end() );
   for ( it = emails.begin(); it != end; ++it ) {
     QRadioButton *button = new QRadioButton( *it, box );
     d->mButtonGroup->addButton( button );
     layout->addWidget( button );
-    if ( (*it) == current ) {
+    if ( ( *it ) == current ) {
       button->setChecked( true );
     }
   }
