@@ -1,22 +1,22 @@
 /*
-    This file is part of the kcal library.
+  This file is part of the kcal library.
 
-    Copyright (c) 2005-2007 David Jarvie <software@astrojar.org.uk>
+  Copyright (c) 2005-2007 David Jarvie <software@astrojar.org.uk>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #include <stdlib.h>
@@ -28,12 +28,11 @@
 #include <ktemporaryfile.h>
 
 #include "testicaltimezones.h"
-#include "testicaltimezones.moc"
 
 QTEST_KDEMAIN( ICalTimeZonesTest, NoGUI )
 
 extern "C" {
-  #include <ical.h>
+  #include <libical/ical.h>
 }
 #include "kcal/icaltimezones.h"
 using namespace KCal;
@@ -338,7 +337,7 @@ void ICalTimeZonesTest::offsetAtZoneTime()
 
     // Standard time: start of definitions at 2:00:00 local time
     QCOMPARE(tz.offsetAtZoneTime(QDTLocal(1967,10,29, 1,59,59), &offset2), -4*3600);
-    QCOMPARE(offset2, -4*3600);
+    QCOMPARE(offset2, -5*3600);
     QCOMPARE(tz.offsetAtZoneTime(QDTLocal(1967,10,29, 2,0,0), &offset2), -5*3600);
     QCOMPARE(offset2, -5*3600);
     QCOMPARE(tz.offsetAtZoneTime(QDTLocal(1967,10,29, 2,59,59), &offset2), -5*3600);
