@@ -38,7 +38,7 @@
 #include <KMimeType>
 #include <KTemporaryFile>
 
-#include <QtGui/QTextDocument> // for Qt::escape() and Qt::mightBeRichText()
+#include <QTextDocument> // for Qt::escape() and Qt::mightBeRichText()
 
 using namespace KCalCore;
 
@@ -496,7 +496,7 @@ void Incidence::setCategories( const QString &catStr )
 
   QStringList::Iterator it;
   for ( it = d->mCategories.begin();it != d->mCategories.end(); ++it ) {
-    *it = (*it).trimmed();
+    *it = ( *it ).trimmed();
   }
 
   updated();
@@ -703,7 +703,7 @@ void Incidence::deleteAttachments( const QString &mime )
   Attachment::List result;
   Attachment::List::Iterator it = d->mAttachments.begin();
   while ( it != d->mAttachments.end() ) {
-    if ( (*it)->mimeType() != mime ) {
+    if ( ( *it )->mimeType() != mime ) {
       result += *it;
     }
     ++it;
@@ -1078,3 +1078,8 @@ QString Incidence::altDescription() const
     return nonKDECustomProperty( ALT_DESC_FIELD );
   }
 }
+
+bool Incidence::supportsGroupwareCommunication() const
+{
+  return type() == TypeEvent || type() == TypeTodo;
+}
