@@ -31,7 +31,7 @@
 
 #include "command.h"
 
-#include "smtp.h"
+#include "smtpsessioninterface.h"
 #include "response.h"
 #include "transactionstate.h"
 
@@ -61,7 +61,7 @@ static sasl_callback_t callbacks[] = {
   // Command (base class)
   //
 
-  Command::Command( SMTPProtocol * smtp, int flags )
+  Command::Command( SMTPSessionInterface * smtp, int flags )
     : mSMTP( smtp ),
       mComplete( false ), mNeedResponse( false ), mFlags( flags )
   {
@@ -80,7 +80,7 @@ static sasl_callback_t callbacks[] = {
     mComplete = false;
   }
 
-  Command * Command::createSimpleCommand( int which, SMTPProtocol * smtp ) {
+  Command * Command::createSimpleCommand( int which, SMTPSessionInterface * smtp ) {
     switch ( which ) {
     case STARTTLS: return new StartTLSCommand( smtp );
     case DATA:     return new DataCommand( smtp );
@@ -103,14 +103,6 @@ static sasl_callback_t callbacks[] = {
     return mSMTP->startSsl();
   }
 
-  bool Command::isUsingSsl() const {
-    return mSMTP->isUsingSsl();
-  }
-
-  bool Command::isAutoSsl() const {
-    return mSMTP->isAutoSsl();
-  }
-
   bool Command::haveCapability( const char * cap ) const {
     return mSMTP->haveCapability( cap );
   }
@@ -176,7 +168,7 @@ static sasl_callback_t callbacks[] = {
       return true;
     } else {
       //kDebug(7112) << "TLS negotiation failed!";
-      mSMTP->messageBox( KIO::SlaveBase::Information,
+      mSMTP->informationMessageBox(
                          i18n("Your SMTP server claims to "
                              "support TLS, but negotiation "
                              "was unsuccessful.\nYou can "
@@ -194,7 +186,7 @@ static sasl_callback_t callbacks[] = {
   //
   // AUTH - rfc 2554
   //
-  AuthCommand::AuthCommand( SMTPProtocol * smtp,
+  AuthCommand::AuthCommand( SMTPSessionInterface * smtp,
                             const char *mechanisms,
                             const QString &aFQDN,
                             KIO::AuthInfo &ai )
@@ -304,11 +296,11 @@ static sasl_callback_t callbacks[] = {
       cmd = mUngetSASLResponse;
       mUngetSASLResponse = 0;
     } else if ( mFirstTime ) {
-      QString firstCommand = "AUTH " + QString::fromLatin1( mMechusing );
+      QString firstCommand = QLatin1String("AUTH ") + QString::fromLatin1( mMechusing );
 
       challenge = QByteArray::fromRawData( mOut, mOutlen ).toBase64();
       if ( !challenge.isEmpty() ) {
-        firstCommand += ' ';
+        firstCommand += QLatin1Char(' ');
         firstCommand += QString::fromLatin1( challenge.data(), challenge.size() );
       }
       cmd = firstCommand.toLatin1();
@@ -350,7 +342,7 @@ static sasl_callback_t callbacks[] = {
           mSMTP->error( KIO::ERR_COULD_NOT_LOGIN,
               ( mMechusing ? i18n("Your SMTP server does not support %1.", QString::fromLatin1( mMechusing ) )
               : i18n("Your SMTP server does not support (unspecified method).") )
-                        + '\n' + chooseADifferentMsg + '\n' + r.errorMessage() );
+                        + QLatin1Char('\n') + chooseADifferentMsg + QLatin1Char('\n') + r.errorMessage() );
         }
         else
           mSMTP->error( KIO::ERR_COULD_NOT_LOGIN,
@@ -391,7 +383,7 @@ static sasl_callback_t callbacks[] = {
     if ( r.code() == 250 )
       return true;
 
-    ts->setMailFromFailed( mAddr, r );
+    ts->setMailFromFailed( QString::fromLatin1(mAddr), r );
     return false;
   }
 
@@ -414,7 +406,7 @@ static sasl_callback_t callbacks[] = {
       return true;
     }
 
-    ts->addRejectedRecipient( mAddr, r.errorMessage() );
+    ts->addRejectedRecipient( QString::fromLatin1(mAddr), r.errorMessage() );
     return false;
   }
 
@@ -542,12 +534,12 @@ static sasl_callback_t callbacks[] = {
   QByteArray TransferCommand::prepare( const QByteArray & ba ) {
     if ( ba.isEmpty() )
       return 0;
-    if ( mSMTP->metaData("lf2crlf+dotstuff") == "slave" ) {
+    if ( mSMTP->lf2crlfAndDotStuffingRequested() ) {
       kDebug(7112) << "performing dotstuffing and LF->CRLF transformation";
       return dotstuff_lf2crlf( ba, mLastChar );
     } else {
       mLastChar = ba[ ba.size() - 1 ];
-      return QByteArray( ba.data(), ba.size() + 1 );
+      return ba;
     }
   }
 
