@@ -291,34 +291,10 @@ bool TransportManager::configureTransport( Transport *transport, QWidget *parent
     return true; // No way to know here if the user cancelled or not.
   }
 
-  QPointer<KDialog> dialog = new KDialog( parent );
-  TransportConfigWidget *configWidget = 0;
-  switch ( transport->type() ) {
-    case Transport::EnumType::SMTP:
-      {
-        configWidget = new SMTPConfigWidget( transport, dialog );
-        break;
-      }
-    case Transport::EnumType::Sendmail:
-      {
-        configWidget =  new SendmailConfigWidget( transport, dialog );
-        break;
-      }
-    default:
-      {
-        Q_ASSERT( false );
-        delete dialog;
-        return false;
-      }
-  }
-  dialog->setMainWidget( configWidget );
-  dialog->setCaption( i18n( "Configure account" ) );
-  dialog->setButtons( KDialog::Ok | KDialog::Cancel );
-  bool okClicked = ( dialog->exec() == QDialog::Accepted );
-  if ( okClicked ) {
-    configWidget->apply(); // calls transport->writeConfig()
-  }
-  delete dialog;
+  QPointer<TransportConfigDialog> transportConfigDialog = new TransportConfigDialog(transport, parent);
+  transportConfigDialog->setCaption( i18n( "Configure account" ) );
+  bool okClicked = ( transportConfigDialog->exec() == QDialog::Accepted );
+  delete transportConfigDialog;
   return okClicked;
 }
 
